==> osmo-hnbgw_1.2.1.tar.xz: BUILD/README.md <==
osmo-hnbgw - Osmocom hNodeB Implementation
===========================================

This repository contains a C-language implementation of a 3G Home NodeB Gateway (OsmoHNBGW).
It is part of the [Osmocom](https://osmocom.org/) Open Source Mobile Communications
project.

You can use it to interface Iuh-speaking Home NodeB (HnodeB), such as
osmo-hnodeb or ip.access nano3g, to Iu-speaking MSCs and SGSNs.

Homepage
--------

The official homepage of the project is
https://osmocom.org/projects/osmohnbgw/wiki

GIT Repository
--------------

You can clone from the official osmo-hnbgw.git repository using

	git clone git://git.osmocom.org/osmo-hnbgw.git

There is a cgit interface at https://git.osmocom.org/osmo-hnbgw/

Documentation
-------------

User Manuals and VTY reference manuals are [optionally] built in PDF form
as part of the build process.

Pre-rendered PDF version of the current "master" can be found at
[User Manual](https://ftp.osmocom.org/docs/latest/osmohnbgw-usermanual.pdf)
as well as the [VTY Reference Manual](https://ftp.osmocom.org/docs/latest/osmohnbgw-vty-reference.pdf)


Mailing List
------------

Discussions related to osmo-hnbgw are happening on the
openbsc@lists.osmocom.org mailing list, please see
https://lists.osmocom.org/mailman/listinfo/openbsc for subscription
options and the list archive.

Please observe the [Osmocom Mailing List
Rules](https://osmocom.org/projects/cellular-infrastructure/wiki/Mailing_List_Rules)
when posting.

Contributing
------------

Our coding standards are described at
https://osmocom.org/projects/cellular-infrastructure/wiki/Coding_standards

We us a gerrit based patch submission/review process for managing
contributions.  Please see
https://osmocom.org/projects/cellular-infrastructure/wiki/Gerrit for
more details

The current patch queue for osmo-hnbgw can be seen at
https://gerrit.osmocom.org/#/q/project:osmo-hnbgw+status:open

==> osmo-hnbgw_1.7.0.tar.xz: BUILD/README.md <==
osmo-hnbgw - Osmocom hNodeB Implementation
===========================================

This repository contains a C-language implementation of a 3G Home NodeB Gateway (OsmoHNBGW).
It is part of the [Osmocom](https://osmocom.org/) Open Source Mobile Communications
project.

You can use it to interface Iuh-speaking Home NodeB (HnodeB), such as
osmo-hnodeb or ip.access nano3g, to Iu-speaking MSCs and SGSNs.

Homepage
--------

The official homepage of the project is
https://osmocom.org/projects/osmohnbgw/wiki

GIT Repository
--------------

You can clone from the official osmo-hnbgw.git repository using

	git clone https://gitea.osmocom.org/cellular-infrastructure/osmo-hnbgw

There is a web interface at https://gitea.osmocom.org/cellular-infrastructure/osmo-hnbgw

Documentation
-------------

User Manuals and VTY reference manuals are [optionally] built in PDF form
as part of the build process.

Pre-rendered PDF version of the current "master" can be found at
[User Manual](https://ftp.osmocom.org/docs/latest/osmohnbgw-usermanual.pdf)
as well as the [VTY Reference Manual](https://ftp.osmocom.org/docs/latest/osmohnbgw-vty-reference.pdf)


Mailing List
------------

Discussions related to osmo-hnbgw are happening on the
openbsc@lists.osmocom.org mailing list, please see
https://lists.osmocom.org/mailman/listinfo/openbsc for subscription
options and the list archive.

Please observe the [Osmocom Mailing List
Rules](https://osmocom.org/projects/cellular-infrastructure/wiki/Mailing_List_Rules)
when posting.

Contributing
------------

Our coding standards are described at
https://osmocom.org/projects/cellular-infrastructure/wiki/Coding_standards

We us a gerrit based patch submission/review process for managing
contributions.  Please see
https://osmocom.org/projects/cellular-infrastructure/wiki/Gerrit for
more details

The current patch queue for osmo-hnbgw can be seen at
https://gerrit.osmocom.org/#/q/project:osmo-hnbgw+status:open
